package com.siwei.rsmonitoring.service;

import java.util.List;
import com.siwei.rsmonitoring.domain.TDkjbxxSc;

/**
 * 地块基本信息审查Service接口
 * 
 * @author siwei
 * @date 2025-02-12
 */
public interface ITDkjbxxScService 
{
    /**
     * 查询地块基本信息审查
     * 
     * @param id 地块基本信息审查主键
     * @return 地块基本信息审查
     */
    public TDkjbxxSc selectTDkjbxxScById(String id);
    public TDkjbxxSc selectTDkjbxxScInfo(String dkid, String auditflowStep, String auditflowId);

    /**
     * 查询地块基本信息审查列表
     * 
     * @param tDkjbxxSc 地块基本信息审查
     * @return 地块基本信息审查集合
     */
    public List<TDkjbxxSc> selectTDkjbxxScList(TDkjbxxSc tDkjbxxSc);

    /**
     * 新增地块基本信息审查
     * 
     * @param tDkjbxxSc 地块基本信息审查
     * @return 结果
     */
    public int insertTDkjbxxSc(TDkjbxxSc tDkjbxxSc);

    /**
     * 新增地块基本信息审查
     *
     * @param tDkjbxxSc 地块基本信息审查
     * @return 结果
     */
    public int addTDkjbxxSc(TDkjbxxSc tDkjbxxSc);

    /**
     * 修改地块基本信息审查
     * 
     * @param tDkjbxxSc 地块基本信息审查
     * @return 结果
     */
    public int updateTDkjbxxSc(TDkjbxxSc tDkjbxxSc);

    /**
     * 批量删除地块基本信息审查
     * 
     * @param ids 需要删除的地块基本信息审查主键集合
     * @return 结果
     */
    public int deleteTDkjbxxScByIds(String[] ids);

    /**
     * 删除地块基本信息审查信息
     * 
     * @param id 地块基本信息审查主键
     * @return 结果
     */
    public int deleteTDkjbxxScById(String id);
}
